@@ -2,7 +2,8 @@
 **	msql.c	- 
 **
 **
-** Copyright (c) 1993  David J. Hughes
+** Copyright (c) 1993-95  David J. Hughes
+** Copyright (c) 1995   Hughes Technologies Pty Ltd
 **
 ** Permission to use, copy, and distribute for non-commercial purposes,
 ** is hereby granted without fee, providing that the above copyright
@@ -29,6 +30,10 @@ static char RCS_id[] =
 #include "common/portability.h"
 
 #include "msql.h"
+#include "version.h"
+
+
+#define	MAX_LEN 15 * 1024
 
 
 usage()
@@ -101,8 +106,9 @@ handleQuery(sock, q)
 	char	*q;
 {
 	char	*nq,
-		sepBuf[5 * 1024];
+		sepBuf[MAX_LEN];
 	int	off,
+		maxLen,
 		length;
 	m_result *result;
 	m_row	cur;
@@ -140,6 +146,7 @@ handleQuery(sock, q)
 	*/
 	(void)bzero(sepBuf,sizeof(sepBuf));
 	strcat(sepBuf," +");
+	maxLen = 1;
 	while((curField = msqlFetchField(result)))
 	{
 		switch(curField->type)
@@ -165,6 +172,13 @@ handleQuery(sock, q)
 						curField->length);
 				break;
 		}
+		maxLen += length;
+		if (maxLen >= MAX_LEN)
+		{
+			printf("\n\nRow length is too long to be displayed\n");
+			msqlFreeResult(result);
+			return;
+		}
 		bufFill(sepBuf,0,length,'-');
 		strcat(sepBuf,"-+");
 	}
@@ -269,7 +283,7 @@ editQuery(q)
 {
 	char	*filename,
 		*editor,
-		combuf[80];
+		combuf[1024];
 	int	fd;
 
 	filename = tmpnam(NULL);
@@ -288,8 +302,8 @@ editQuery(q)
 	sprintf(combuf,"%s %s",editor,filename);
 	system(combuf);
 	fd = open(filename,O_RDONLY, 0777);
-	bzero(q,2048);
-	read(fd,q,2048);
+	bzero(q,MAX_LEN);
+	read(fd,q,MAX_LEN);
 	close(fd);
 	unlink(filename);
 }
@@ -300,7 +314,7 @@ main(argc,argv)
 	int	argc;
 	char	*argv[];
 {
-	char	qbuf[2048],
+	char	qbuf[MAX_LEN],
 		*cp,
 		*host = NULL;
 	int	newQ = 1,
@@ -309,7 +323,8 @@ main(argc,argv)
 		inString = 0,
 		c,
 		argsLeft,
-		errFlag = 0;
+		errFlag = 0,
+		qLen = 0;
 	register u_int inchar;
 	extern	int optind;
 	extern	char *optarg;
@@ -365,6 +380,7 @@ main(argc,argv)
 	*/
 
 	printf("Welcome to the miniSQL monitor.  Type \\h for help.\n\n");
+		
 	inchar = EOF+1;
 	(void)bzero(qbuf,sizeof(qbuf));
 	cp = qbuf;
@@ -372,6 +388,13 @@ main(argc,argv)
 	while(!feof(stdin))
 	{
 		inchar = fgetc(stdin);
+		qLen ++;
+		if (qLen == MAX_LEN)
+		{
+			printf("\n\n\nError : Query text too long ( > %d bytes!)\n\n", MAX_LEN);
+			printf("Check your query to ensure that there isn't an unclosed text field.\n\n");
+			exit(1);
+		}
 		if (inchar == '\\')
 		{
 			if (inString)
@@ -396,6 +419,7 @@ main(argc,argv)
 				case 'g':
 					handleQuery(sock,qbuf);
 					newQ = 1;
+					qLen = 0;
 					inString = 0;
 					printf("\nmSQL > ");
 					prompt=0;
@@ -408,6 +432,7 @@ main(argc,argv)
 					printf("    -> ");
 					prompt=0;
 					cp = qbuf + strlen(qbuf);
+					qLen = strlen(qbuf);
 					break;
 				case 'q':
 					msqlClose(sock);
