@@ -2,7 +2,8 @@
 **	msql_lex.c	- 
 **
 **
-** Copyright (c) 1993  David J. Hughes
+** Copyright (c) 1993-95  David J. Hughes
+** Copyright (c) 1995  Hughes Technologies
 **
 ** Permission to use, copy, and distribute for non-commercial purposes,
 ** is hereby granted without fee, providing that the above copyright
@@ -327,6 +328,7 @@ u_char *readTextLiteral(tok)
 int yylex()
 {
 	REG	u_char	c;
+	REG	u_char	t;
 	int	tokval;
 	static	u_char dummyBuf[2];
 
@@ -377,6 +379,18 @@ int yylex()
 					state = 5;
 					break;
 				}
+				if (c == '.')
+				{
+					t = yyGet();
+					if ( isdigit(t) ) 
+					{
+						yyUnget();
+						state = 7;
+						break;
+					} 
+					else
+						yyUnget();
+				}
 				if (c == '-' || c == '+')
 				{
 					state = 9;
@@ -517,6 +531,11 @@ int yylex()
 					state = 5;
 					break;
 				}
+				if (c == '.')
+				{
+					state = 7;
+					break;
+				}
 				state = 999;
 				break;
 
