@@ -2,7 +2,8 @@
 **	msql_priv.h	- Private (internal) definitions
 **
 **
-** Copyright (c) 1993  David J. Hughes
+** Copyright (c) 1993-95  David J. Hughes
+** Copyright (c) 1995  Hughes Technologies Pty Ltd
 **
 ** Permission to use, copy, and distribute for non-commercial purposes,
 ** is hereby granted without fee, providing that the above copyright
@@ -16,6 +17,11 @@
 
 #include "version.h"
 
+#ifdef NEW_DB
+#  include <limits.h>
+#  include <db.h>
+#endif
+
 
 /***************************************************************************
 *	Configuration parameters 
@@ -109,7 +115,7 @@ typedef struct tlist_s {
 
 
 /* 
-** Order clause list element  (not used as yet!)
+** Order clause list element 
 */
 typedef struct order_s {		
 	char	table[NAME_LEN + 1],
@@ -140,8 +146,13 @@ typedef struct cache_s {
 		rowLen,
 		keyLen,
 		result;
+	u_int	numRows;
 	field_t	*def;
 
+#ifdef	NEW_DB
+	DB	*dbp;
+#endif
+
 #ifdef	HAVE_MMAP
 	int	remapData,
 		remapKey,
