@@ -2,7 +2,8 @@
 **	msql_proc.c	- 
 **
 **
-** Copyright (c) 1993  David J. Hughes
+** Copyright (c) 1993-95  David J. Hughes
+** Copyright (c) 1995  Hughes Technologies Pty Ltd
 **
 ** Permission to use, copy, and distribute for non-commercial purposes,
 ** is hereby granted without fee, providing that the above copyright
@@ -390,6 +391,39 @@ int msqlAddField(ident,type,length,notNull,priKey)
 
 	msqlTrace(TRACE_IN,"msqlAddField()");
 
+	if (*(ident->seg2))
+	{
+		name = ident->seg2;
+		table = ident->seg1;
+	}
+	else
+	{
+		name = ident->seg1;
+		table = NULL;
+	}
+
+
+	/*
+	** Look for duplicate field names on a table create
+	*/
+	if (type != 0)
+	{
+		new = fieldHead;
+		while(new)
+		{
+			if (strcmp(new->name,name) == 0)
+			{
+				sprintf(packet,
+					"-1:Duplicate field name '%s'\n",
+					name);
+				writePkt(outSock);
+				msqlTrace(TRACE_OUT,"msqlAddField()");
+				return(-1);
+			}
+			new = new->next;
+		}
+	}
+
 	if (priKey)
 	{
 		if (havePriKey)
@@ -407,16 +441,6 @@ int msqlAddField(ident,type,length,notNull,priKey)
 	}
 
 
-	if (*(ident->seg2))
-	{
-		name = ident->seg2;
-		table = ident->seg1;
-	}
-	else
-	{
-		name = ident->seg1;
-		table = NULL;
-	}
 	new = (field_t *)malloc(sizeof(field_t));
 	if (table)
 	{
@@ -675,7 +699,6 @@ msqlProcessQuery()
 	switch(command)
 	{
 		case SELECT: 
-			setProcTitle("Q=Select");
 			if (!msqlCheckPerms(READ_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
@@ -687,7 +710,6 @@ msqlProcessQuery()
 				orderHead,curDB);
 			break;
 		case CREATE: 
-			setProcTitle("Q=Create");
 			if (!msqlCheckPerms(WRITE_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
@@ -698,7 +720,6 @@ msqlProcessQuery()
 			res = msqlCreate(tableHead->name,fieldHead,curDB);
 			break;
 		case UPDATE: 
-			setProcTitle("Q=Update");
 			if (!msqlCheckPerms(RW_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
@@ -710,7 +731,6 @@ msqlProcessQuery()
 				curDB);
 			break;
 		case INSERT: 
-			setProcTitle("Q=Insert");
 			if (!msqlCheckPerms(WRITE_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
@@ -721,7 +741,6 @@ msqlProcessQuery()
 			res = msqlInsert(tableHead->name,fieldHead,curDB);
 			break;
 		case DELETE: 
-			setProcTitle("Q=Delete");
 			if (!msqlCheckPerms(WRITE_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
@@ -732,7 +751,6 @@ msqlProcessQuery()
 			res = msqlDelete(tableHead->name,condHead,curDB);
 			break;
 		case DROP: 
-			setProcTitle("Q=Drop");
 			if (!msqlCheckPerms(WRITE_ACCESS))
 			{
 				sprintf(packet,"-1:Access Denied\n");
