@@ -2,7 +2,8 @@
 **	msqld.c	- 
 **
 **
-** Copyright (c) 1993  David J. Hughes
+** Copyright (c) 1993-95  David J. Hughes
+** Copyright (c) 1995  Hughes Technologies Pty Ltd
 **
 ** Permission to use, copy, and distribute for non-commercial purposes,
 ** is hereby granted without fee, providing that the above copyright
@@ -59,7 +60,6 @@
 extern  char    *yytext;
 extern	int	yylineno;
 extern	int	yydebug;
-extern	int	titleFlag;
 
 extern	char	errMsg[];
 
@@ -320,42 +320,6 @@ RETSIGTYPE puntClient(sig)
 }
 
 
-char	*Arg0;
-
-void setProcTitle(va_alist)
-        va_dcl
-{
-	va_list args;
-	char    msg[1024],
-		*fmt;
-	int     module;
-
-	if (!titleFlag)
-		return;
-	va_start(args);
-	fmt = (char *)va_arg(args, char *);
-	if (!fmt)
-		return;
-	strcpy(msg,"mSQL : ");
-	(void)vsprintf(msg + strlen(msg),fmt,args);
-	va_end(args);
-	if (strlen(msg) > 50)
-	{
-		*(msg+50) = 0;
-	}
-	strcpy(Arg0,BLANK_ARGV);
-	strcpy(Arg0,msg);
-}
-
-initProcTitle(argv)
-	char	*argv[];
-{
-	
-	if (!titleFlag)
-		return;
-	Arg0 = argv[0];
-	setProcTitle("Starting");
-} 
 
 setupSignals()
 {
@@ -377,6 +341,9 @@ setupSignals()
 #ifdef SIGPIPE
 	signal(SIGPIPE,puntClient);
 #endif
+#ifdef SIGTERM
+	signal(SIGTERM,puntServer);
+#endif
 }
 
 
@@ -402,22 +369,6 @@ main(argc,argv)
 		path[255];
 	FILE	*pidFile;
 
-	/*
-	** See if we have to re-exec ourselves for procTitle space
-	*/
-	if (titleFlag)
-	{
-		if (*argv[0] != ' ')
-		{
-			prog = argv[0];
-			argv[0] = BLANK_ARGV;
-			execvp(prog,argv);
-			perror("Exec failed");
-			exit(1);
-		}
-	}
-
-
 	/*
 	** We have enough space for fiddling with the argv, continue
 	*/
@@ -434,7 +385,6 @@ main(argc,argv)
 	initNet();
 	initServer();
 	initBackend();
-	initProcTitle(argv);
 	(void)sprintf(path,"%s/msqld.pid",PID_DIR);
 	pidFile = fopen(path,"w");
 	if (!pidFile)
@@ -454,13 +404,11 @@ main(argc,argv)
 	msqlDebug(MOD_GENERAL,"miniSQL debug mode.  Waiting for connections.\n");
 	while(1)
 	{
-		(void)bzero(&readFDs,sizeof(fd_set));
 		(void)bcopy(&clientFDs,&readFDs,sizeof(fd_set));
 		FD_SET(IPsock,&readFDs);
 #ifdef HAVE_SYS_UN_H
 		FD_SET(UNIXsock,&readFDs);
 #endif
-		setProcTitle("Idle - %d clients",numCons);
 		if(select(MAX_SOCK_NUM+1,&readFDs,0,0,0) < 0)
 			continue;
 
@@ -481,8 +429,10 @@ main(argc,argv)
 #endif
 		if (sock)
 		{
-			struct	sockaddr_in cAddr;
-			int	cAddrLen;
+			struct	sockaddr_in 	cAddr;
+			struct	sockaddr	dummy;
+			int	cAddrLen,
+				dummyLen;
 
 			cAddrLen = sizeof(struct sockaddr_in);
 			newSock = accept(sock, (struct sockaddr *)&cAddr, 
@@ -492,6 +442,12 @@ main(argc,argv)
 				perror("Error in accept ");
 				continue;
 			}
+			dummyLen = sizeof(struct sockaddr);
+			if (getsockname(newSock,&dummy, &dummyLen) < 0)
+			{
+				perror("Error on new connection socket");
+				continue;
+			}
 			if (conArray[newSock].db)
 			{
 				safeFree(conArray[newSock].db);
@@ -627,7 +583,6 @@ main(argc,argv)
 			switch(command)
 			{
 			    case INIT_DB:
-				setProcTitle("Init DB");
 				cp=(char *)strtok(packet+2,"\n\r");
 				strcpy(dbname,cp);
 				msqlDebug(MOD_GENERAL,"DBName = %s\n", dbname);
@@ -671,13 +626,11 @@ main(argc,argv)
 				break;
 
 			    case DB_LIST:
-				setProcTitle("DB List");
 				curSock = comSock;
 				msqlListDBs(comSock);
 				break;
 
 			    case TABLE_LIST:
-				setProcTitle("Table List");
 				if (!conArray[comSock].db)
 				{
 					sendError(comSock, NO_DB_ERROR);
@@ -688,7 +641,6 @@ main(argc,argv)
 				break;
 
 			    case FIELD_LIST:
-				setProcTitle("Field List");
 				if (!conArray[comSock].db)
 				{
 					sendError(comSock,NO_DB_ERROR);
@@ -718,7 +670,6 @@ main(argc,argv)
 				break;
 		
 			    case CREATE_DB:
-				setProcTitle("Create DB");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
 					sendError(comSock,PERM_DENIED_ERROR);
@@ -731,7 +682,6 @@ main(argc,argv)
 				break;
 
 			    case DROP_DB:	
-				setProcTitle("Drop DB");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
 					sendError(comSock,PERM_DENIED_ERROR);
@@ -744,7 +694,6 @@ main(argc,argv)
 				break;
 
 			    case RELOAD_ACL:
-				setProcTitle("Reload ACL");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
 					sendError(comSock,PERM_DENIED_ERROR);
@@ -756,7 +705,6 @@ main(argc,argv)
 				break;
 
 			    case SHUTDOWN:
-				setProcTitle("Shutdown");
 				if (!msqlCheckLocal(conArray + comSock))
 				{
 					sendError(comSock,PERM_DENIED_ERROR);
